
Overview
===========


:Title: 
:Nickname: D6C4
:Summary: 
:SubChallenges: 
:Synapse page: https://www.synapse.org/#!Synapse:syn2887788
:Leaderboard: https://www.synapse.org/#!Synapse:syn2887788/wiki/72181

.. contents::


Scoring
---------

::

    from dreamtools import D6C4
    s = D6C4()
    filename = s.download_template() 
    s.score(filename) 


